RiceAddress

Struct RiceAddress 

pub struct RiceAddress(/* private fields */);
A socket address.

Implementations

Source

impl RiceAddress

pub fn new(addr: SocketAddr) -> Self

Create a new RiceAddress.

pub fn into_c_full(self) -> *const RiceAddress

Convert this RiceAddress into it’s C API equivalent.

The returned value should be converted back into the Rust equivalent using RiceAddress::into_rust_full() in order to free the resource.

pub unsafe fn into_rice_full(value: *const RiceAddress) -> Box<Self>

Consume a C representation of a RiceAddress into the Rust equivalent.

pub unsafe fn into_rice_none(value: *const RiceAddress) -> Self

Copy a C representation of a RiceAddress into the Rust equivalent.

pub fn inner(self) -> SocketAddr

The inner representation of the RiceAddress.

Methods from Deref<Target = SocketAddr>

1.7.0 · Source

pub fn ip(&self) -> IpAddr

Returns the IP address associated with this socket address.

Examples
use std::net::{IpAddr, Ipv4Addr, SocketAddr};

let socket = SocketAddr::new(IpAddr::V4(Ipv4Addr::new(127, 0, 0, 1)), 8080);
assert_eq!(socket.ip(), IpAddr::V4(Ipv4Addr::new(127, 0, 0, 1)));
1.0.0 · Source

pub fn port(&self) -> u16

Returns the port number associated with this socket address.

Examples
use std::net::{IpAddr, Ipv4Addr, SocketAddr};

let socket = SocketAddr::new(IpAddr::V4(Ipv4Addr::new(127, 0, 0, 1)), 8080);
assert_eq!(socket.port(), 8080);
1.16.0 · Source

pub fn is_ipv4(&self) -> bool

Returns true if the IP address in this SocketAddr is an IPv4 address, and false otherwise.

Examples
use std::net::{IpAddr, Ipv4Addr, SocketAddr};

let socket = SocketAddr::new(IpAddr::V4(Ipv4Addr::new(127, 0, 0, 1)), 8080);
assert_eq!(socket.is_ipv4(), true);
assert_eq!(socket.is_ipv6(), false);
1.16.0 · Source

pub fn is_ipv6(&self) -> bool

Returns true if the IP address in this SocketAddr is an IPv6 address, and false otherwise.

Examples
use std::net::{IpAddr, Ipv6Addr, SocketAddr};

let socket = SocketAddr::new(IpAddr::V6(Ipv6Addr::new(0, 0, 0, 0, 0, 65535, 0, 1)), 8080);
assert_eq!(socket.is_ipv4(), false);
assert_eq!(socket.is_ipv6(), true);